Message

Enum Message 

pub enum Message {
Show 13 variants Auth { token: String, client_id: Uuid, }, AuthOk { tunnel_id: Uuid, }, AuthFail { reason: String, }, Register { name: String, protocol: ServiceProtocol, local_port: u16, remote_port: u16, }, RegisterOk { service_id: Uuid, }, RegisterFail { reason: String, }, Connect { service_id: Uuid, connection_id: Uuid, client_addr: String, }, ConnectAck { connection_id: Uuid, }, ConnectFail { connection_id: Uuid, reason: String, }, Heartbeat { timestamp: u64, }, HeartbeatAck { timestamp: u64, }, Unregister { service_id: Uuid, }, Disconnect { reason: String, },
}
Protocol messages

Variants



Auth

Client authentication request (C->S)

Fields

token: String

Authentication token

client_id: Uuid

Client identifier



AuthOk

Server authentication success (S->C)

Fields

tunnel_id: Uuid

Assigned tunnel ID



AuthFail

Server authentication failure (S->C)

Fields

reason: String

Failure reason



Register

Client service registration (C->S)

Fields

name: String

Service name

protocol: ServiceProtocol

Protocol type

local_port: u16

Local port on client

remote_port: u16

Requested remote port (0 = auto-assign)



RegisterOk

Server registration success (S->C)

Fields

service_id: Uuid

Assigned service ID



RegisterFail

Server registration failure (S->C)

Fields

reason: String

Failure reason



Connect

Server connection announcement (S->C)

Fields

service_id: Uuid

Service ID for this connection

connection_id: Uuid

Unique connection ID

client_addr: String

Client address (IP:port)



ConnectAck

Client connection acknowledgment (C->S)

Fields

connection_id: Uuid

Connection ID being acknowledged



ConnectFail

Client connection failure (C->S)

Fields

connection_id: Uuid

Connection ID that failed

reason: String

Failure reason



Heartbeat

Heartbeat (bidirectional)

Fields

timestamp: u64

Unix timestamp in milliseconds



HeartbeatAck

Heartbeat acknowledgment (bidirectional)

Fields

timestamp: u64

Echo of original timestamp



Unregister

Client service unregistration (C->S)

Fields

service_id: Uuid

Service ID to unregister



Disconnect

Server disconnect notification (S->C)

Fields

reason: String

Disconnect reason

Implementations

Source

impl Message

pub const fn message_type(&self) -> MessageType

Get the message type

pub fn encode(&self) -> Vec<u8>

Encode the message to binary format

pub fn decode(bytes: &[u8]) -> Result<(Self, usize)>

Decode a message from binary format

Returns the decoded message and the number of bytes consumed.

Errors

Returns an error if:

  • The buffer is too short for a complete message
  • The message type is unknown
  • The payload is malformed or contains invalid data